emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
* [Patch 1/2] org-publish
@ 2010-12-01 10:06 Manuel Giraud
  2011-02-08 16:52 ` [Accepted] [Orgmode,1/2] org-publish Bastien Guerry
  2011-02-08 16:55 ` [Patch 1/2] org-publish Bastien
  0 siblings, 2 replies; 3+ messages in thread
From: Manuel Giraud @ 2010-12-01 10:06 UTC (permalink / raw)
  To: emacs-orgmode

[-- Attachment #1: Type: text/plain, Size: 290 bytes --]


Hi,

This first patch adds sort options to the sitemap. In addition to
alphabetical order, one can choose chronological or anti-chronological
ordering of sitemap entries. To retrieve file date, it tries to parse
the "#+date" keyword and if not present defaults to file modification
time.


[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: sitemap-chrono.patch --]
[-- Type: text/x-patch, Size: 7480 bytes --]

diff --git a/doc/org.texi b/doc/org.texi
index 4e8eb63..c283503 100644
--- a/doc/org.texi
+++ b/doc/org.texi
@@ -10859,9 +10859,13 @@ of links to all files in the project.
 (default) or @code{last} to display folders first or last,
 respectively.  Any other value will mix files and folders.
 
-@item @code{:sitemap-alphabetically}
-@tab The site map is normally sorted alphabetically.  Set this explicitly to
-@code{nil} to turn off sorting.
+@item @code{:sitemap-sort-files}
+@tab How the files are sorted in the site map.  Set this
+@code{alphabetically} (default), @code{chronologically} or
+@code{anti-chronologically}. @code{chronologically} sorts the files with
+older date first while @code{anti-chronologically} sorts the files with newer
+date first. @code{alphabetically} sorts the files alphabetically. The date of
+a file is retrieved with @code{org-publish-find-date}.
 
 @item @code{:sitemap-ignore-case}
 @tab Should sorting be case-sensitive?  Default @code{nil}.
diff --git a/lisp/org-publish.el b/lisp/org-publish.el
index c66cd29..edc0b5c 100644
--- a/lisp/org-publish.el
+++ b/lisp/org-publish.el
@@ -186,8 +186,9 @@ sitemap of files or summary page for a given project.
                            Set this to `first' (default) or `last' to
                            display folders first or last, respectively.
                            Any other value will mix files and folders.
-  :sitemap-alphabetically  The site map is normally sorted alphabetically.
-                           Set this explicitly to nil to turn off sorting.
+  :sitemap-sort-files      The site map is normally sorted alphabetically.
+                           You can change this behaviour setting this to
+                           `chronologically', `anti-chronologically' or nil.
   :sitemap-ignore-case     Should sorting be case-sensitive?  Default nil.
 
 The following properties control the creation of a concept index.
@@ -233,13 +234,18 @@ Any changes made by this hook will be saved."
   :group 'org-publish
   :type 'hook)
 
-(defcustom org-publish-sitemap-sort-alphabetically t
-  "Should sitemaps be sorted alphabetically by default?
+(defcustom org-publish-sitemap-sort-files 'alphabetically
+  "How sitemaps files should be sorted by default?
+Possible values are `alphabetically', `chronologically', `anti-chronologically' and nil.
+If `alphabetically', files will be sorted alphabetically.
+If `chronologically', files will be sorted with older modification time first.
+If `anti-chronologically', files will be sorted with newer modification time first.
+nil won't sort files.
 
 You can overwrite this default per project in your
-`org-publish-project-alist', using `:sitemap-alphabetically'."
+`org-publish-project-alist', using `:sitemap-sort-files'."
   :group 'org-publish
-  :type 'boolean)
+  :type 'symbol)
 
 (defcustom org-publish-sitemap-sort-folders 'first
   "A symbol, denoting if folders are sorted first in sitemaps.
@@ -360,30 +366,37 @@ This splices all the components into the list."
     (nreverse (org-publish-delete-dups (delq nil rtn)))))
 
 
-(defvar sitemap-alphabetically)
+(defvar sitemap-sort-files)
 (defvar sitemap-sort-folders)
 (defvar sitemap-ignore-case)
 (defvar sitemap-requested)
 (defun org-publish-compare-directory-files (a b)
-  "Predicate for `sort', that sorts folders-first/last and alphabetically."
+  "Predicate for `sort', that sorts folders and files for sitemap."
   (let ((retval t))
-    (when (or sitemap-alphabetically sitemap-sort-folders)
-      ;; First we sort alphabetically:
-      (when sitemap-alphabetically
-        (let* ((adir (file-directory-p a))
-               (aorg (and (string-match "\\.org$" a) (not adir)))
-               (bdir (file-directory-p b))
-               (borg (and (string-match "\\.org$" b) (not bdir)))
-               (A (if aorg
-                      (concat (file-name-directory a)
-                              (org-publish-find-title a)) a))
-               (B (if borg
-                      (concat (file-name-directory b)
-                              (org-publish-find-title b)) b)))
-          (setq retval (if sitemap-ignore-case
-			   (not (string-lessp (upcase B) (upcase A)))
-			 (not (string-lessp B A))))))
-
+    (when (or sitemap-sort-files sitemap-sort-folders)
+      ;; First we sort files:
+      (when sitemap-sort-files
+	(cond ((equal sitemap-sort-files 'alphabetically)
+	       (let* ((adir (file-directory-p a))
+		      (aorg (and (string-match "\\.org$" a) (not adir)))
+		      (bdir (file-directory-p b))
+		      (borg (and (string-match "\\.org$" b) (not bdir)))
+		      (A (if aorg
+			     (concat (file-name-directory a)
+				     (org-publish-find-title a)) a))
+		      (B (if borg
+			     (concat (file-name-directory b)
+				     (org-publish-find-title b)) b)))
+		 (setq retval (if sitemap-ignore-case
+				  (not (string-lessp (upcase B) (upcase A)))
+				(not (string-lessp B A))))))
+		((or (equal sitemap-sort-files 'chronologically)
+		     (equal sitemap-sort-files 'anti-chronologically))
+		 (let ((A (org-publish-find-date a))
+		       (B (org-publish-find-date b)))
+		   (setq retval (if (equal sitemap-sort-files 'chronologically)
+				    (<= A B)
+				  (>= A B)))))))
       ;; Directory-wise wins:
       (when sitemap-sort-folders
         ;; a is directory, b not:
@@ -438,10 +451,14 @@ matching filenames."
 	  (if (plist-member project-plist :sitemap-sort-folders)
 	      (plist-get project-plist :sitemap-sort-folders)
 	    org-publish-sitemap-sort-folders))
-	 (sitemap-alphabetically
-	  (if (plist-member project-plist :sitemap-alphabetically)
-	      (plist-get project-plist :sitemap-alphabetically)
-	    org-publish-sitemap-sort-alphabetically))
+	 (sitemap-sort-files
+	  (cond ((plist-member project-plist :sitemap-sort-files)
+		 (plist-get project-plist :sitemap-sort-files))
+		;; For backward compatibility:
+		((plist-member project-plist :sitemap-alphabetically)
+		 (if (plist-get project-plist :sitemap-alphabetically)
+		     'alphabetically nil))
+		(t org-publish-sitemap-sort-files)))
 	 (sitemap-ignore-case
 	  (if (plist-member project-plist :sitemap-ignore-case)
 	      (plist-get project-plist :sitemap-ignore-case)
@@ -481,10 +498,10 @@ matching filenames."
 		 (e (plist-get (cdr prj) :exclude))
 		 (i (plist-get (cdr prj) :include))
 		 (xm (concat "^" b (if r ".+" "[^/]+") "\\.\\(" x "\\)$")))
-	    (when (or
+	    (when
+		(or
 		   (and 
-		    i 
-		    (member filename 
+		  i (member filename
 			    (mapcar 
 			     (lambda (file) (expand-file-name file b))
 			     i)))
@@ -780,6 +797,23 @@ Default for SITEMAP-FILENAME is 'sitemap.org'."
     (org-publish-cache-set-file-property file :title title)
     title)))
 
+(defun org-publish-find-date (file)
+  "Find the date of FILE in project.
+If FILE provides a #+date keyword use it else use the file
+system's modification time."
+  (let ((visiting (find-buffer-visiting file)))
+    (save-excursion
+      (switch-to-buffer (or visiting (find-file file)))
+      (let* ((plist (org-infile-export-plist))
+	     (date (plist-get plist :date)))
+	(unless visiting
+	  (kill-buffer (current-buffer)))
+	(if date
+	    (let ((dt (org-time-string-to-time date)))
+	      (+ (lsh (car dt) 16) (cadr dt)))
+	  (when (file-exists-p file)
+	    (org-publish-cache-ctime-of-src file)))))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Interactive publishing functions
 

[-- Attachment #3: Type: text/plain, Size: 19 bytes --]


-- 
Manuel Giraud

[-- Attachment #4: Type: text/plain, Size: 201 bytes --]

_______________________________________________
Emacs-orgmode mailing list
Please use `Reply All' to send replies to the list.
Emacs-orgmode@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-orgmode

^ permalink raw reply related	[flat|nested] 3+ messages in thread

* [Accepted] [Orgmode,1/2] org-publish
  2010-12-01 10:06 [Patch 1/2] org-publish Manuel Giraud
@ 2011-02-08 16:52 ` Bastien Guerry
  2011-02-08 16:55 ` [Patch 1/2] org-publish Bastien
  1 sibling, 0 replies; 3+ messages in thread
From: Bastien Guerry @ 2011-02-08 16:52 UTC (permalink / raw)
  To: emacs-orgmode

Patch 429 (http://patchwork.newartisans.com/patch/429/) is now "Accepted".

Maintainer comment: none

This relates to the following submission:

http://mid.gmane.org/%3C87mxop7qp3.fsf%40univ-nantes.fr%3E

Here is the original message containing the patch:

> Content-Type: text/plain; charset="utf-8"
> MIME-Version: 1.0
> Content-Transfer-Encoding: 7bit
> Subject: [Orgmode,1/2] org-publish
> Date: Wed, 01 Dec 2010 15:06:16 -0000
> From: Manuel Giraud <manuel.giraud@univ-nantes.fr>
> X-Patchwork-Id: 429
> Message-Id: <87mxop7qp3.fsf@univ-nantes.fr>
> To: emacs-orgmode <emacs-orgmode@gnu.org>
> 
> Hi,
> 
> This first patch adds sort options to the sitemap. In addition to
> alphabetical order, one can choose chronological or anti-chronological
> ordering of sitemap entries. To retrieve file date, it tries to parse
> the "#+date" keyword and if not present defaults to file modification
> time.
> 
> 
> diff --git a/doc/org.texi b/doc/org.texi
> index 4e8eb63..c283503 100644
> --- a/doc/org.texi
> +++ b/doc/org.texi
> @@ -10859,9 +10859,13 @@ of links to all files in the project.
>  (default) or @code{last} to display folders first or last,
>  respectively.  Any other value will mix files and folders.
>  
> -@item @code{:sitemap-alphabetically}
> -@tab The site map is normally sorted alphabetically.  Set this explicitly to
> -@code{nil} to turn off sorting.
> +@item @code{:sitemap-sort-files}
> +@tab How the files are sorted in the site map.  Set this
> +@code{alphabetically} (default), @code{chronologically} or
> +@code{anti-chronologically}. @code{chronologically} sorts the files with
> +older date first while @code{anti-chronologically} sorts the files with newer
> +date first. @code{alphabetically} sorts the files alphabetically. The date of
> +a file is retrieved with @code{org-publish-find-date}.
>  
>  @item @code{:sitemap-ignore-case}
>  @tab Should sorting be case-sensitive?  Default @code{nil}.
> diff --git a/lisp/org-publish.el b/lisp/org-publish.el
> index c66cd29..edc0b5c 100644
> --- a/lisp/org-publish.el
> +++ b/lisp/org-publish.el
> @@ -186,8 +186,9 @@ sitemap of files or summary page for a given project.
>                             Set this to `first' (default) or `last' to
>                             display folders first or last, respectively.
>                             Any other value will mix files and folders.
> -  :sitemap-alphabetically  The site map is normally sorted alphabetically.
> -                           Set this explicitly to nil to turn off sorting.
> +  :sitemap-sort-files      The site map is normally sorted alphabetically.
> +                           You can change this behaviour setting this to
> +                           `chronologically', `anti-chronologically' or nil.
>    :sitemap-ignore-case     Should sorting be case-sensitive?  Default nil.
>  
>  The following properties control the creation of a concept index.
> @@ -233,13 +234,18 @@ Any changes made by this hook will be saved."
>    :group 'org-publish
>    :type 'hook)
>  
> -(defcustom org-publish-sitemap-sort-alphabetically t
> -  "Should sitemaps be sorted alphabetically by default?
> +(defcustom org-publish-sitemap-sort-files 'alphabetically
> +  "How sitemaps files should be sorted by default?
> +Possible values are `alphabetically', `chronologically', `anti-chronologically' and nil.
> +If `alphabetically', files will be sorted alphabetically.
> +If `chronologically', files will be sorted with older modification time first.
> +If `anti-chronologically', files will be sorted with newer modification time first.
> +nil won't sort files.
>  
>  You can overwrite this default per project in your
> -`org-publish-project-alist', using `:sitemap-alphabetically'."
> +`org-publish-project-alist', using `:sitemap-sort-files'."
>    :group 'org-publish
> -  :type 'boolean)
> +  :type 'symbol)
>  
>  (defcustom org-publish-sitemap-sort-folders 'first
>    "A symbol, denoting if folders are sorted first in sitemaps.
> @@ -360,30 +366,37 @@ This splices all the components into the list."
>      (nreverse (org-publish-delete-dups (delq nil rtn)))))
>  
>  
> -(defvar sitemap-alphabetically)
> +(defvar sitemap-sort-files)
>  (defvar sitemap-sort-folders)
>  (defvar sitemap-ignore-case)
>  (defvar sitemap-requested)
>  (defun org-publish-compare-directory-files (a b)
> -  "Predicate for `sort', that sorts folders-first/last and alphabetically."
> +  "Predicate for `sort', that sorts folders and files for sitemap."
>    (let ((retval t))
> -    (when (or sitemap-alphabetically sitemap-sort-folders)
> -      ;; First we sort alphabetically:
> -      (when sitemap-alphabetically
> -        (let* ((adir (file-directory-p a))
> -               (aorg (and (string-match "\\.org$" a) (not adir)))
> -               (bdir (file-directory-p b))
> -               (borg (and (string-match "\\.org$" b) (not bdir)))
> -               (A (if aorg
> -                      (concat (file-name-directory a)
> -                              (org-publish-find-title a)) a))
> -               (B (if borg
> -                      (concat (file-name-directory b)
> -                              (org-publish-find-title b)) b)))
> -          (setq retval (if sitemap-ignore-case
> -			   (not (string-lessp (upcase B) (upcase A)))
> -			 (not (string-lessp B A))))))
> -
> +    (when (or sitemap-sort-files sitemap-sort-folders)
> +      ;; First we sort files:
> +      (when sitemap-sort-files
> +	(cond ((equal sitemap-sort-files 'alphabetically)
> +	       (let* ((adir (file-directory-p a))
> +		      (aorg (and (string-match "\\.org$" a) (not adir)))
> +		      (bdir (file-directory-p b))
> +		      (borg (and (string-match "\\.org$" b) (not bdir)))
> +		      (A (if aorg
> +			     (concat (file-name-directory a)
> +				     (org-publish-find-title a)) a))
> +		      (B (if borg
> +			     (concat (file-name-directory b)
> +				     (org-publish-find-title b)) b)))
> +		 (setq retval (if sitemap-ignore-case
> +				  (not (string-lessp (upcase B) (upcase A)))
> +				(not (string-lessp B A))))))
> +		((or (equal sitemap-sort-files 'chronologically)
> +		     (equal sitemap-sort-files 'anti-chronologically))
> +		 (let ((A (org-publish-find-date a))
> +		       (B (org-publish-find-date b)))
> +		   (setq retval (if (equal sitemap-sort-files 'chronologically)
> +				    (<= A B)
> +				  (>= A B)))))))
>        ;; Directory-wise wins:
>        (when sitemap-sort-folders
>          ;; a is directory, b not:
> @@ -438,10 +451,14 @@ matching filenames."
>  	  (if (plist-member project-plist :sitemap-sort-folders)
>  	      (plist-get project-plist :sitemap-sort-folders)
>  	    org-publish-sitemap-sort-folders))
> -	 (sitemap-alphabetically
> -	  (if (plist-member project-plist :sitemap-alphabetically)
> -	      (plist-get project-plist :sitemap-alphabetically)
> -	    org-publish-sitemap-sort-alphabetically))
> +	 (sitemap-sort-files
> +	  (cond ((plist-member project-plist :sitemap-sort-files)
> +		 (plist-get project-plist :sitemap-sort-files))
> +		;; For backward compatibility:
> +		((plist-member project-plist :sitemap-alphabetically)
> +		 (if (plist-get project-plist :sitemap-alphabetically)
> +		     'alphabetically nil))
> +		(t org-publish-sitemap-sort-files)))
>  	 (sitemap-ignore-case
>  	  (if (plist-member project-plist :sitemap-ignore-case)
>  	      (plist-get project-plist :sitemap-ignore-case)
> @@ -481,10 +498,10 @@ matching filenames."
>  		 (e (plist-get (cdr prj) :exclude))
>  		 (i (plist-get (cdr prj) :include))
>  		 (xm (concat "^" b (if r ".+" "[^/]+") "\\.\\(" x "\\)$")))
> -	    (when (or
> +	    (when
> +		(or
>  		   (and 
> -		    i 
> -		    (member filename 
> +		  i (member filename
>  			    (mapcar 
>  			     (lambda (file) (expand-file-name file b))
>  			     i)))
> @@ -780,6 +797,23 @@ Default for SITEMAP-FILENAME is 'sitemap.org'."
>      (org-publish-cache-set-file-property file :title title)
>      title)))
>  
> +(defun org-publish-find-date (file)
> +  "Find the date of FILE in project.
> +If FILE provides a #+date keyword use it else use the file
> +system's modification time."
> +  (let ((visiting (find-buffer-visiting file)))
> +    (save-excursion
> +      (switch-to-buffer (or visiting (find-file file)))
> +      (let* ((plist (org-infile-export-plist))
> +	     (date (plist-get plist :date)))
> +	(unless visiting
> +	  (kill-buffer (current-buffer)))
> +	(if date
> +	    (let ((dt (org-time-string-to-time date)))
> +	      (+ (lsh (car dt) 16) (cadr dt)))
> +	  (when (file-exists-p file)
> +	    (org-publish-cache-ctime-of-src file)))))))
> +
>  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
>  ;;; Interactive publishing functions
>  
> 

^ permalink raw reply	[flat|nested] 3+ messages in thread

* Re: [Patch 1/2] org-publish
  2010-12-01 10:06 [Patch 1/2] org-publish Manuel Giraud
  2011-02-08 16:52 ` [Accepted] [Orgmode,1/2] org-publish Bastien Guerry
@ 2011-02-08 16:55 ` Bastien
  1 sibling, 0 replies; 3+ messages in thread
From: Bastien @ 2011-02-08 16:55 UTC (permalink / raw)
  To: Manuel Giraud; +Cc: emacs-orgmode

Hi Manuel,

Manuel Giraud <manuel.giraud@univ-nantes.fr> writes:

> This first patch adds sort options to the sitemap. In addition to
> alphabetical order, one can choose chronological or anti-chronological
> ordering of sitemap entries. To retrieve file date, it tries to parse
> the "#+date" keyword and if not present defaults to file modification
> time.

I've now applied this patch -- thanks for this contribution.

-- 
 Bastien

^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2011-02-08 16:55 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2010-12-01 10:06 [Patch 1/2] org-publish Manuel Giraud
2011-02-08 16:52 ` [Accepted] [Orgmode,1/2] org-publish Bastien Guerry
2011-02-08 16:55 ` [Patch 1/2] org-publish Bastien

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).